/*
  Device for User Interface customization examples.
  See https://stargate-system.com/examples/ui for full description

  Example ready to use with Raspberry Pico W.
  To use with other boards, uncomment WiFi library include relevant to your board

  Before uploading, replace <YOUR WIFI NAME> and <YOUR WIFI PASSWORD>
  with your WiFi credentials
*/

// Uncomment below if using ESP-8266
// #include <ESP8266WiFi.h>

// Uncomment below if using ESP-32
// #include <WiFi.h>

#include <WiFiGateDevice.h>

int R = 2;
int G = 3;
int B = 4;

WiFiGateDevice device("<YOUR WIFI NAME>", "<YOUR WIFI PASSWORD>");
GateInt red = device.factory.createInt("input");
GateInt green = device.factory.createInt("input");
GateInt blue = device.factory.createInt("input");

void setup() {
  device.setName("Color Picker");
  device.info = "color";
  initColors();
  device.start();
}

void loop() {
  device.loop();
}

void initColors() {
  pinMode(R, OUTPUT);
  pinMode(G, OUTPUT);
  pinMode(B, OUTPUT);

  red.info = "color:red";
  red.setMin(0);
  red.setMax(255);

  green.info = "color:green";
  green.setMin(0);
  green.setMax(255);

  blue.info = "color:blue";
  blue.setMin(0);
  blue.setMax(255);

  red.onRemoteChange = onRedChange;
  green.onRemoteChange = onGreenChange;
  blue.onRemoteChange = onBlueChange;
}

void onRedChange() {
  analogWrite(R, red.getValue());
}

void onGreenChange() {
  analogWrite(G, green.getValue());
}

void onBlueChange() {
  analogWrite(B, blue.getValue());
}
